@@ -17,7 +17,7 @@ out <- prsim(data=runoff, number_sim=1, marginal="GEV", GoFtest = "KS", n_par=3)
 
 sim <- out$simulation
 # p_val <- out$p_val
-par(mai=c(.9,.9,.1,.1))
+# par(mai=c(.9,.9,.1,.1))
 plot(sim$timestamp[1:1000], sim$Qobs[1:1000], type="l", 
      xlab="Time [d]", ylab=expression(paste("Discharge [m"^3,"/s]")))
 matlines(sim$timestamp[1:1000], sim[1:1000, grep("r", names(sim))],
